import { GuildScheduledEvent, Message, MessageCreateOptions, TextChannel } from "discord.js";
import { ScheduledTask } from "node-cron";
import { v4 as uuid } from "uuid";
import { client, yavinJellyfinHandler } from "../..";
import { config } from "../configuration";
import { createDateStringFromEvent } from "../helper/dateHelper";
import { Maybe } from "../interfaces";
import { logger } from "../logger";
import { Emotes, NONE_OF_THAT } from "../constants";


export const name = 'guildScheduledEventCreate'



export async function execute(event: GuildScheduledEvent) {
	const requestId = uuid()

	if (event.name.toLowerCase().includes("!nextwp")) {
		logger.info("Event was a placeholder event to start a new watchparty and voting. Creating vote!", { guildId: event.guildId, requestId })
		logger.debug("Renaming event", { guildId: event.guildId, requestId })
		event.edit({ name: "Watchparty - Voting offen" })
		const movies = await yavinJellyfinHandler.getRandomMovieNames(5, event.guildId, requestId)

		logger.info(`Got ${movies.length} random movies. Creating voting`, { guildId: event.guildId, requestId })
		logger.debug(`Movies: ${JSON.stringify(movies)}`, { guildId: event.guildId, requestId })

		const announcementChannel: Maybe<TextChannel> = client.getAnnouncementChannelForGuild(event.guildId)
		if (!announcementChannel) {
			logger.error("Could not find announcement channel. Aborting", { guildId: event.guildId, requestId })
			return
		}
		logger.debug(`Found channel ${JSON.stringify(announcementChannel, null, 2)}`, { guildId: event.guildId, requestId })

		if (!event.scheduledStartAt) {
			logger.info("EVENT DOES NOT HAVE STARTDATE; CANCELLING", { guildId: event.guildId, requestId })
			return
		}
		let message = `[Abstimmung] für https://discord.com/events/${event.guildId}/${event.id}\n<@&${config.bot.announcement_role}> Es gibt eine neue Abstimmung für die nächste Watchparty ${createDateStringFromEvent(event, event.guildId, requestId)}! Stimme hierunter für den nächsten Film ab!\n`

		for (let i = 0; i < movies.length; i++) {
			message = message.concat(Emotes[i]).concat(": ").concat(movies[i]).concat("\n")
		}
		message = message.concat(NONE_OF_THAT).concat(": Wenn dir nichts davon gefällt.")

		const options: MessageCreateOptions = {
			allowedMentions: { parse: ["roles"] },
			content: message,
		}

		const sentMessage: Message<true> = await (await announcementChannel.fetch()).send(options)

		for (let i = 0; i < movies.length; i++) {
			sentMessage.react(Emotes[i])
		}
		sentMessage.react(NONE_OF_THAT)

		// sentMessage.pin() //todo: uncomment when bot has permission to pin messages. Also update closepoll.ts to only fetch pinned messages
	}
}

